@@ -21,6 +21,15 @@ class Conditions(DeserializableObject):
                     return _condition
         return None
 
+    def getFirst(self):
+        if self.__conditions:
+            return self.__conditions[0]
+        return None
+
+    def getLast(self):
+        if self.__conditions:
+            return self.__conditions[len(self.__conditions) - 1]
+
     def getAll(self):
         return self.__conditions
 
